''' Permite llevar el control de una fecha mediante un archivo de texto '''

# Librerías
import pandas as pd
from pathlib import Path

class Fecha:
	''' Representa una fecha almacenada en un archivo de texto '''

	def __init__(self, archivo: str, fecha = pd.Timestamp.now()):
		ruta = Path(__file__).resolve().parent
		self.archivo = ruta / archivo

		if not self.archivo.exists():
			self.guardar(fecha)

	def __lt__(self, other: pd.Timestamp):
		''' Regresa verdadero si la fecha almacenada en el archivo es menor a la fecha dada '''

		return self.actual.date() < other.date()

	@property
	def actual(self):
		''' Regresa la fecha almacenada en el archivo '''

		return pd.Timestamp(self.archivo.read_text())

	def guardar(self, fecha: pd.Timestamp):
		''' Guarda la fecha dada en el archivo '''

		self.archivo.write_text(str(fecha.strftime('%Y-%m-%d')))

	def avanzar(self, dias: int = 1):
		''' Avanza la fecha almacenada en el archivo '''

		self.guardar(self.actual + pd.Timedelta(days = dias))